robotpy-installer
=================

The RobotPy installer can be used to:

* Install RobotPy on your RoboRIO
* Install python packages on your RoboRIO via pip
* Install binary packages from NI and distributed by the RobotPy project via opkg

It can install downloaded packages on your RoboRIO without requiring internet
access, which makes it usable in a competition (provided you downloaded the
necessary packages when you were connected to the internet).

For more information about installing and using the RobotPy installer, see 
`http://robotpy.readthedocs.io/en/stable/install/packages.html <http://robotpy.readthedocs.io/en/stable/install/packages.html>`_
